@@ -224,16 +224,17 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
     for index in partition:
         partition_all_names.append([iGd.vs[index]['name'] for index in index])
 
-    list2d_all =  [x for x in partition_all_names]
-    all_nodes_index =  list(itertools.chain(*list2d_all))
+    #list2d_all =  [x for x in partition_all_names]
+    #all_nodes_index =  list(itertools.chain(*list2d_all))
+    all_nodes_index =  list(itertools.chain(*partition_all_names))
 
     nodes_NN_index = []
     for part in partition_all_names:
       part1 = [x for x in part if 'nnn' in x]
       nodes_NN_index.append(part1)
 
-    other_nodes = [x for x in all_nodes_index if x not in nodes_NN_index ]
-
+    #other_nodes = [x for x in all_nodes_index if x not in nodes_NN_index ]
+    other_nodes = [x for x in all_nodes_index if x not in list(itertools.chain(*nodes_NN_index)) ]
     ## all com
     com_a = 0
     com_aa = []
@@ -286,7 +287,8 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
     for node in other_nodes:
         color = 'gray'
         #node = iGd.vs[index]['name']
-        node1 = node[:-2]
+        #node1 = node[:-2]
+        node1 = re.sub(r'[2][a-zA-Z]{2}',"2",node)
         if 'vvv' in node:
           shape = 'square'   # shape  image, circularImage, diamond, dot, star, triangle, triangleDown, square and icon.
           degree = dict(Gdc.degree)[node]
