@@ -10,7 +10,7 @@ def coreNLP():
     nlp.add_pipe('coreferee')
     print('Coreference is Available')
   except:
-    print('Coreference is NOT available, otherwise install "coreferee" and import separately before install "keypartx"!!!')
+    print('Coreference is NOT available, otherwise install "coreferee" and import separately before REINSTALL "keypartx"!!!')
   return nlp 
 
 nlp = coreNLP()
